#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 store
version:              0.7.20
visibility:           public
id:                   store-0.7.20-39btVmIMzxNEQ884R9O1H2
key:                  store-0.7.20-39btVmIMzxNEQ884R9O1H2
license:              MIT
copyright:            2016 FP Complete
maintainer:           Michael Sloan <mgsloan@gmail.com>
homepage:             https://github.com/mgsloan/store#readme
synopsis:             Fast binary serialization
category:             Serialization, Data
abi:                  e007d85c80eca57b7baf5f39238b7ac0
exposed:              True
exposed-modules:
    Data.Store Data.Store.Internal Data.Store.TH Data.Store.TH.Internal
    Data.Store.TypeHash Data.Store.TypeHash.Internal Data.Store.Version
    System.IO.ByteBuffer

hidden-modules:       Data.Store.Impl
import-dirs:          /usr/lib/ghc-9.6.6/site-local/store-0.7.20
library-dirs:         /usr/lib/ghc-9.6.6/site-local/store-0.7.20
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/store-0.7.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-store
hs-libraries:         HSstore-0.7.20-39btVmIMzxNEQ884R9O1H2
depends:
    array-0.5.6.0 async-2.2.6-JCsfEU6uxaM3jchWvvttZs base-4.18.2.1
    base-orphans-0.9.4-IAPPnARdMwIA3nWXQXPDH6
    base64-bytestring-1.2.1.0-ErbO7EG1OVTInceY2TwMCE
    bifunctors-5.6.3-3xCQ8aHpZ1ZAppdLkg81G7 bytestring-0.11.5.3
    containers-0.6.7 contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    cryptohash-sha1-0.11.101.0-LkTbORfwvCT5EdDxRYFRu3 deepseq-1.4.8.1
    directory-1.3.8.5 filepath-1.4.300.1
    free-5.2-FRLNqXYeqnXLimHJeeHiJb ghc-prim-0.10.0
    hashable-1.4.7.0-KEzkDU36XICA02zRvxfUEu
    hspec-2.11.7-7gnoQNyRayg3C2dCwMP172
    hspec-smallcheck-0.5.3-5CbCbR8ZTh25FgfCqy15Z8 integer-gmp-1.1
    lifted-base-0.2.3.12-B11c2YtQs0zHH6ENnFeuab
    monad-control-1.0.3.1-FKQevUTXtN116pyhgQjb7S
    mono-traversable-1.0.21.0-9Gn7BM4CBxu5Wmd00Xy1JY
    network-3.1.4.0-IFm2hwedGEHKSyVo9U41Hp
    primitive-0.9.1.0-J4tB0B9QUoG4JNvPWMquph
    resourcet-1.3.0-NkgSS2nOUY5UPO0Rt6LWs
    safe-0.3.21-9y1UyAWqaZD9sixo0tZ214
    smallcheck-1.2.1.1-EmvvtU2HIuf2ry3mSCi1Fv
    store-core-0.4.4.7-CqMCNXQNUZA6pe9j70zNXt
    syb-0.7.3-KT9hwgimXgJGhH797KmsNL template-haskell-2.20.0.0
    text-2.0.2 th-lift-0.8.7-JMijAGUD56uaCh66C6Lgg
    th-lift-instances-0.1.20-KXWx4aAycUHDTSCTBLr4s
    th-orphans-0.13.17-23sQ8ArXaMfI5kvldcnYoq
    th-reify-many-0.1.10-Cto2LfM9atDC3pEE71qyOW
    th-utilities-0.2.5.2-LOLtvziVx224TrTC8cgCbm time-1.12.2
    transformers-0.6.1.0
    unordered-containers-0.2.21-8pZ5d13ZaJk3LfHcqeQHmo
    vector-0.13.2.0-Bce9rIW4lAD9r12sFleKX
    void-0.7.4-Ab78HEYVlxC2PerDGXO6Wd

haddock-interfaces:   /usr/share/doc/haskell-store/html/store.haddock
haddock-html:         /usr/share/doc/haskell-store/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

